#[repr(transparent)]pub struct Ctrl0(pub u32);Expand description
Contains the offsets of AB and CD in the RAM.
Tuple Fields
0: u32Implementations
Sourceimpl Ctrl0
impl Ctrl0
Sourcepub const fn abbpair(&self) -> Abbpair
pub const fn abbpair(&self) -> Abbpair
Which bank-pair the offset ABOFF is within. This must be 0 if only 2-up
Sourcepub const fn set_abbpair(&mut self, val: Abbpair)
pub const fn set_abbpair(&mut self, val: Abbpair)
Which bank-pair the offset ABOFF is within. This must be 0 if only 2-up
Sourcepub const fn aboff(&self) -> bool
pub const fn aboff(&self) -> bool
Word or DWord Offset of AB values, with B at [2]=0 and A at [2]=1 as far as the code sees (normally will be an interleaved bank so only sequential to AHB). Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the CD values if 4-up
Sourcepub const fn set_aboff(&mut self, val: bool)
pub const fn set_aboff(&mut self, val: bool)
Word or DWord Offset of AB values, with B at [2]=0 and A at [2]=1 as far as the code sees (normally will be an interleaved bank so only sequential to AHB). Word offset only allowed if 32 bit operation. Ideally not in the same RAM as the CD values if 4-up
Sourcepub const fn cdbpair(&self) -> Cdbpair
pub const fn cdbpair(&self) -> Cdbpair
Which bank-pair the offset CDOFF is within. This must be 0 if only 2-up
Sourcepub const fn set_cdbpair(&mut self, val: Cdbpair)
pub const fn set_cdbpair(&mut self, val: Cdbpair)
Which bank-pair the offset CDOFF is within. This must be 0 if only 2-up