#[repr(transparent)]pub struct Dreg(pub u32);Expand description
D register
Tuple Fields
0: u32Implementations
Sourceimpl Dreg
impl Dreg
Sourcepub const fn reg_value(&self) -> u32
pub const fn reg_value(&self) -> u32
Register to be fed into Multiplier. Is not normally written or read by application, but is available when accelerator not busy.
Sourcepub const fn set_reg_value(&mut self, val: u32)
pub const fn set_reg_value(&mut self, val: u32)
Register to be fed into Multiplier. Is not normally written or read by application, but is available when accelerator not busy.