nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Res1

Struct Res1 

#[repr(transparent)]
pub struct Res1(pub u32);
Result register 1

Tuple Fields

0: u32

Implementations

Source

impl Res1

pub const fn reg_value(&self) -> u32

Register to hold working result (from multiplier, adder/xor, etc). Is not normally written or read by application, but is available when accelerator not busy.

pub const fn set_reg_value(&mut self, val: u32)

Register to hold working result (from multiplier, adder/xor, etc). Is not normally written or read by application, but is available when accelerator not busy.